@@ -49,6 +49,7 @@ SPINNER_ATTRS = [
     "balloon",
     "balloon2",
     "betaWave",
+    "bluePulse",
     "bounce",
     "bouncingBall",
     "bouncingBar",
@@ -74,6 +75,8 @@ SPINNER_ATTRS = [
     "dots9",
     "dqpb",
     "earth",
+    "fingerDance",
+    "fistBump",
     "flip",
     "grenade",
     "growHorizontal",
@@ -84,9 +87,12 @@ SPINNER_ATTRS = [
     "line",
     "line2",
     "material",
+    "mindblown",
     "monkey",
     "moon",
     "noise",
+    "orangeBluePulse",
+    "orangePulse",
     "pipe",
     "point",
     "pong",
@@ -95,10 +101,13 @@ SPINNER_ATTRS = [
     "simpleDots",
     "simpleDotsScrolling",
     "smiley",
+    "soccerHeader",
+    "speaker",
     "squareCorners",
     "squish",
     "star",
     "star2",
+    "timeTravel",
     "toggle",
     "toggle10",
     "toggle11",
